@@ -9,7 +9,7 @@
 
 import builtins
 import errno
-import functools
+import contextlib
 import io
 import itertools
 import os
@@ -141,10 +141,9 @@ def setup_pidfile_fixtures(testcase):
 
     def get_scenario_option(testcase, key, default=None):
         value = default
-        try:
+        with contextlib.suppress(
+                NameError, TypeError, AttributeError, KeyError):
             value = testcase.scenario[key]
-        except (NameError, TypeError, AttributeError, KeyError):
-            pass
         return value
 
     func_patcher_os_getpid = unittest.mock.patch.object(
@@ -432,7 +431,7 @@ class TimeoutPIDLockFile_TestCase(scaffold.TestCase):
         mock_func_acquire.assert_called_with(instance, expected_timeout)
 
 
-# Copyright © 2008–2022 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2023 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
